==> apache-wicket-8.17.0.zip: apache-wicket-8.17.0/wicket-core/src/test/java/org/apache/wicket/request/resource/ResourceUrlSanitizerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.request.resource;

import org.apache.wicket.util.tester.WicketTestCase;
import org.junit.Test;

/**
 * @author Pedro Santos
 */
public class ResourceUrlSanitizerTest extends WicketTestCase
{

	@Test
	public void appCanRunWithNoSanitizer()
	{

		tester.getApplication().getResourceSettings().setUrlSanitizer(null);

		tester.executeUrl(
			"wicket/resource/org.apache.wicket.request.resource.PackageResourceReferenceTest/a.css");

		assertFalse(tester.getLastResponseAsString().isEmpty());
	}

	@Test
	public void createAResourceOutsideTheCache()
	{

		tester.getApplication().getResourceSettings()
			.setUrlSanitizer(new PackageResourceUrlSanitizer());

		tester.executeUrl(
			"wicket/resource/org.apache.wicket.request.resource.PackageResourceReferenceTest/a.css");

		assertFalse(tester.getLastResponseAsString().isEmpty());
	}

	@Test
	public void dontCreateAResourceOutsideTheCache()
	{

		tester.getApplication().getResourceSettings().setUrlSanitizer(new EveryInputAsDirty());

		tester.executeUrl(
			"wicket/resource/org.apache.wicket.request.resource.PackageResourceReferenceTest/a.css");

		assertTrue(tester.getLastResponseAsString().isEmpty());
	}

	static class EveryInputAsDirty implements IResourceUrlSanitizer
	{
		@Override
		public ResourceReference.UrlAttributes sanitize(
			ResourceReference.UrlAttributes urlAttributes, Class<?> scope, String name)
		{
			return null;
		}
	}

}

==> apache-wicket-9.21.0.zip: apache-wicket-9.21.0/wicket-core/src/test/java/org/apache/wicket/request/resource/ResourceUrlSanitizerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.request.resource;

import org.apache.wicket.util.tester.WicketTestCase;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

/**
 * @author Pedro Santos
 */
public class ResourceUrlSanitizerTest extends WicketTestCase
{

	@Test
	void appCanRunWithNoSanitizer()
	{

		tester.getApplication().getResourceSettings().setUrlSanitizer(null);

		tester.executeUrl(
			"wicket/resource/org.apache.wicket.core.request.resource.PackageResourceReferenceTest/a.css");

		Assertions.assertFalse(tester.getLastResponseAsString().isEmpty());
	}

	@Test
	void createAResourceOutsideTheCache()
	{

		tester.getApplication().getResourceSettings()
			.setUrlSanitizer(new PackageResourceUrlSanitizer());

		tester.executeUrl(
			"wicket/resource/org.apache.wicket.core.request.resource.PackageResourceReferenceTest/a.css");

		Assertions.assertFalse(tester.getLastResponseAsString().isEmpty());
	}

	@Test
	void dontCreateAResourceOutsideTheCache()
	{

		tester.getApplication().getResourceSettings().setUrlSanitizer(new EveryInputAsDirty());

		tester.executeUrl(
			"wicket/resource/org.apache.wicket.core.request.resource.PackageResourceReferenceTest/a.css");

		Assertions.assertTrue(tester.getLastResponseAsString().isEmpty());
	}

	static class EveryInputAsDirty implements IResourceUrlSanitizer
	{
		@Override
		public ResourceReference.UrlAttributes sanitize(
			ResourceReference.UrlAttributes urlAttributes, Class<?> scope, String name)
		{
			return null;
		}
	}

}
